# frozen_string_literal: true

class Hermes::Api::Dmo::HousingRequestEntityFormsController < Hermes::Api::Dmo::ApplicationController
  set_instance_for :show_request

  VALID_OPERATORS = %w[$in $nin $ne $gt $gte $lt $lte $eq $regex $all]
  ACCEPTABLE_PARAMS = %w[
    entity_id
    housing_request_id
    applicant_id
    consent_fields
    level
    delegation
    delegation_signed
    entity_form_level_id
    created_at
    updated_at
  ]
  MUTATE_PARAMS = %i[
    entity_id
    level
    housing_request_id
    entity_form_level_id
    consent_fields
    delegation
  ]
  mutate_params_only *MUTATE_PARAMS

  def index
    acceptable_params *ACCEPTABLE_PARAMS
    valid_operators *VALID_OPERATORS
    super
  end

  def actives
    acceptable_params *ACCEPTABLE_PARAMS
    valid_operators *VALID_OPERATORS

    paginate(
      index_aggregation.where(active: true),
      each_serializer: @serializer,
      **@options
    )
  end

  def show_request
    @instance = @model.find_by(id: params[:id])
    return render_json_error(:not_found, :instance_not_found) unless @instance

    entity = Hermes::Entity.readable_by(@user).find_by(id: @instance.entity_id)
    return render_json_error(:unauthorized, :not_reader) unless entity && current_user_roles.include?('entreprise')

    render json: @instance.consent_fields
  end

  def destroy
    return render_json_error(:not_found, :instance_not_found) unless @instance
    return render_json_error(:unauthorized, :not_owned) unless @instance.user_id == @user.id
    return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy

    render(body: nil, status: :no_content)
  end
end