# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class UserRightsController < Hermes::Api::Dmo::ApplicationController

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          right
          type
          title
          group_id
          entity_id
          lessor_id
          user_id
          user_email
          user_first_name
          user_last_name
          user_phone_number
          user_auth_roles
        ].freeze

        REGEX_PARAMS = %w[
        ].freeze

        MUTATE_PARAMS = %i[
          right
          type
          entity_id
          lessor_id
          user_id
        ].freeze
        mutate_params_only(*MUTATE_PARAMS)
        
        
        def right_on_entity(ur = nil, no_params = false)
          return true if current_user.auth_roles&.include?('superadministrateur')
          p = no_params ? {} : mutate_valid_params 
          type = p[:type] || ur&.type
          entity_id = p[:entity_id] || ur&.entity_id
          lessor_id = p[:lessor_id] || ur&.lessor_id

          entity = (type == 'entity') ? Hermes::Entity.find(entity_id) : Hermes::Lessor.find(lessor_id)

          current_user.group_ids.to_array.include?(entity.manager_group_id)
        end


        def create_without_render
          @instance = @model.new(mutate_valid_params)
        end

        def set_instance
          @instance = @model.find_by(id: params[:id], **@query_precision) if params[:id]
        end


        def create
          return render_json_error(:unauthorized, :no_right_on_entity) unless right_on_entity

          super
        end

        def update
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :no_right_on_entity) unless right_on_entity(@instance, true)

          return render json: @instance.errors.messages, status: 422 unless @instance.update(mutate_valid_params)
          render(jsonapi: @instance, serializer: @serializer, status: :ok)
        end

        def destroy
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :no_right_on_entity) unless right_on_entity(@instance, true)
          return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy
          
          render(body: nil, status: :no_content)
        end

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          
          paginate(
            index_aggregation(no_acl: true),
            each_serializer: @serializer,
            **@options
          )
        end

      end
    end
  end
end
