# frozen_string_literal: true
=begin


# exemple d'utilisation
=begin

  hr = Hermes::HousingRequest.find("5e3d823ca70bf25ace59e9eb")

 so=Hermes::BoClient::AddRequestTask.new({housing_request_id: hr.id})
 so.to_xml

ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end

module Hermes
  module BoClient
    class ValidateEntityTask < BaseTask
      
      def initialize(options = {})
        @xsd = "EntrepriseDemande.xsd"
        super(options)
      end
      
      endpoint {'/ws/rest/als/demande/v1/entreprise'}
      
      task_name 'validateEntity'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingRequestMap'
      
      params *%i[
                numGuichet
                refInterne
                dateCreationDemande
              
            }
      ]
      
      def add_if_exists(b, item_name, mapping_name = nil, is_code = false)
        mapping_name ||= item_name
        mapping_value = mapping.send(mapping_name)
        
        b.send(item_name, is_code ? {"code" => mapping_value} : mapping_value) unless mapping_value == nil
      
      end
      
      def to_xml
        namespaces = {
          'xmlns:ns2' => "http://v1.als.ikos.webservice.immobilier.sopra/demande/entrepriseDemande"
        }
        
        
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
          b['ns2'].entrepriseDemande(namespaces) do
            b.numUnique mapping.numUnique do
              b.parent.namespace = nil
            end
            b.refInterneDemande mapping.refInterne do
              b.parent.namespace = nil
            end
            b.idREX mapping.idREX do
              b.parent.namespace = nil
            end
            b.appCommerciale mapping.appCommerciale do
              b.parent.namespace = nil
            end
            b.numSiret mapping.numSiret do
              b.parent.namespace = nil
            end
          end
        end
        
        builder.to_xml
      end
    end
  end
end
